# ***********************************************************************************
# ************************* VUNIT AND LIBRARY INITIALIZATION ************************
# ***********************************************************************************

# Load required libraries from VUnit
from os.path import join, dirname
# The public interface of VUnit
from vunit import VUnit
# Computes the cartesian product of input iterables
from itertools import product
# Load required functions for testcase files load
from os import listdir

# Returns the directory name where the present file (run.py) is located
root = dirname(__file__)

# Create VUnit instance by parsing command line arguments
ui = VUnit.from_argv()

# Add random numbers generation package
ui.add_random()
# Add verification component library
ui.add_verification_components()
# Add communication package
ui.add_com()

# Xilinx XPM library, already compiled for Windows (for simulation with ModelSim)
ui.add_external_library("xpm", join(root, "../../../_external_libs/xpm"))

# Create library 'vunit_lib'
vunit_lib = ui.library("vunit_lib")

# Add all necessary package files
vunit_lib.add_source_files(join(root, "../../../Image/_packages/*.vhd"))
vunit_lib.add_source_files(join(root, "../../../Encoder/_packages/*.vhd"))

# Add all sources files from Image IP
vunit_lib.add_source_files(join(root, "../../../Image/image_coord_control.vhd"))

# Add all sources files from Top IP
vunit_lib.add_source_files(join(root, "../parallel_sync_fifos.vhd"))

# Add testbench file from Top IP
vunit_lib.add_source_files(join(root, "tb_parallel_sync_fifos.vhd"))

# Necessary file (and explicit association for ModelSim) to let the XPM compiled library work
# NOTE: These lines must be added at the end...
vunit_lib.add_source_files(join(root, "../../../_external_libs/glbl.v"))
ui.set_sim_option("modelsim.vsim_flags", ["vunit_lib.glbl"])

# ***********************************************************************************
# ************************************ FUNCTIONS ************************************
# ***********************************************************************************

# To encode the parameters, the script must contain the encode function
def encode(tb_cfg):
    return ",".join(["%s:%s" % (key, str(tb_cfg[key])) for key in tb_cfg])

# A list of parameters are defined, then saved and finally encoded to be in the testbench
def gen_par_sync_fifo_tests(obj, smpl_order, data_width, data_depth, num_par_fifos):
    for smpl_order, data_width, data_depth, num_par_fifos in product(smpl_order, data_width, data_depth, num_par_fifos):
        tb_cfg = dict(
            SMPL_ORDER_PY=smpl_order,
            DATA_WIDTH_PY=data_width,
            DATA_DEPTH_PY=data_depth,
			NUM_PAR_FIFOS_PY=num_par_fifos
        )
        config_name = encode(tb_cfg)
        obj.add_config(name=config_name, generics=dict(encoded_tb_cfg=encode(tb_cfg)))

# ***********************************************************************************
# ****************************** GENERATE TESTBENCHES *******************************
# ***********************************************************************************

# Everytime a new testbench is here requested (it can be the same with different parameters),
# all test cases in the VHDL testbench file will be executed again.
tb_parallel_sync_fifos = vunit_lib.test_bench("tb_parallel_sync_fifos")
for test in tb_parallel_sync_fifos.get_tests():
	gen_par_sync_fifo_tests(test, [0, 1, 2], [16, 32], [1024], [1, 2, 3])

# ***********************************************************************************
# ********************************** MAIN FUNCTION **********************************
# ***********************************************************************************

ui.main()