library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

-- Table E-1: Coordinate Indices and Image Quantities
package param_image is

	constant NX_C	: integer range 1 to 2**16	:= 33;		-- Image X-dimensions 
	constant NY_C	: integer range 1 to 2**16	:= 01;		-- Image Y-dimensions
	constant NZ_C	: integer range 1 to 2**16	:= 02;		-- Image Z-dimensions	

	constant TAU_C	: integer range 0 to 15		:= 0;		-- Number of supplementary information tables (it can also be 0!)	
	constant D_C	: integer range 2 to 32		:= 16;		-- Image dynamic range in bits
	constant DI_C	: integer range 1 to 32		:= 8;		-- Supplementary information integer table bit depth
	constant DF_C	: integer range 1 to 23		:= 16;		-- Supplementary information float table significand bit depth
	constant DE_C	: integer range 2 to 8		:= 6;		-- Supplementary information float table exponent bit depth
	constant BETA_C	: integer range 0 to (2**DE_C-1) := 12;	-- Supplementary information float table exponent bias
	
	-- NOT-MODIFICABLE PARAMETERS -----------------------------------------------------------------------------
	-- Lower (MIN), mid-range (MID) and upper (MAX) sample value limits for "signed" and "unsigned" samples
	constant S_MIN_SGN_C : signed(D_C-1 downto 0)	:= (D_C-1 => '1', others => '0');	-- -2**(D_C-1)
	constant S_MID_SGN_C : signed(D_C-1 downto 0)	:= (others => '0');					-- 0
	constant S_MAX_SGN_C : signed(D_C-1 downto 0)	:= (D_C-1 => '0', others => '1');	-- 2**(D_C-1)-1
	
	constant S_MIN_USN_C : unsigned(D_C-1 downto 0)	:= (others => '0');					-- 0
	constant S_MID_USN_C : unsigned(D_C-1 downto 0)	:= (D_C-1 => '1', others => '0');	-- 2**(D_C-1)
	constant S_MAX_USN_C : unsigned(D_C-1 downto 0)	:= (others => '1');					-- 2**D_C-1
	-----------------------------------------------------------------------------------------------------------

end package param_image;