library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

library work;
use work.param_image.all;
use work.types_image.all;
use work.utils_image.all;

-- Package Declaration Section
package supl_info_tables is	
	
	-- 0 dimensional tables (for unsigned, signed and float types, respectively)
	constant SUPL_TBL_0DIM_USG_00_C	 : unsigned(DI_C-1 downto 0) := x"01";
	constant SUPL_TBL_0DIM_USG_01_C	 : unsigned(DI_C-1 downto 0) := x"02";
	constant SUPL_TBL_0DIM_USG_02_C	 : unsigned(DI_C-1 downto 0) := x"03";
	constant SUPL_TBL_0DIM_USG_03_C	 : unsigned(DI_C-1 downto 0) := x"04";
	constant SUPL_TBL_0DIM_USG_04_C	 : unsigned(DI_C-1 downto 0) := x"05";
	constant SUPL_TBL_0DIM_USG_05_C	 : unsigned(DI_C-1 downto 0) := x"06";
	constant SUPL_TBL_0DIM_USG_06_C	 : unsigned(DI_C-1 downto 0) := x"07";
	constant SUPL_TBL_0DIM_USG_07_C	 : unsigned(DI_C-1 downto 0) := x"08";
	constant SUPL_TBL_0DIM_USG_08_C	 : unsigned(DI_C-1 downto 0) := x"09";
	constant SUPL_TBL_0DIM_USG_09_C	 : unsigned(DI_C-1 downto 0) := x"0A";
	constant SUPL_TBL_0DIM_USG_10_C	 : unsigned(DI_C-1 downto 0) := x"0B";
	constant SUPL_TBL_0DIM_USG_11_C	 : unsigned(DI_C-1 downto 0) := x"0C";
	constant SUPL_TBL_0DIM_USG_12_C	 : unsigned(DI_C-1 downto 0) := x"0D";
	constant SUPL_TBL_0DIM_USG_13_C	 : unsigned(DI_C-1 downto 0) := x"0E";
	constant SUPL_TBL_0DIM_USG_14_C  : unsigned(DI_C-1 downto 0) := x"0F";

	constant SUPL_TBL_0DIM_SGD_00_C	 : signed(DI_C-1 downto 0)	 := x"11";
	constant SUPL_TBL_0DIM_SGD_01_C	 : signed(DI_C-1 downto 0)	 := x"12";
	constant SUPL_TBL_0DIM_SGD_02_C	 : signed(DI_C-1 downto 0)	 := x"13";
	constant SUPL_TBL_0DIM_SGD_03_C	 : signed(DI_C-1 downto 0)	 := x"14";
	constant SUPL_TBL_0DIM_SGD_04_C	 : signed(DI_C-1 downto 0)	 := x"15";
	constant SUPL_TBL_0DIM_SGD_05_C	 : signed(DI_C-1 downto 0)	 := x"16";
	constant SUPL_TBL_0DIM_SGD_06_C	 : signed(DI_C-1 downto 0)	 := x"17";
	constant SUPL_TBL_0DIM_SGD_07_C	 : signed(DI_C-1 downto 0)	 := x"18";
	constant SUPL_TBL_0DIM_SGD_08_C	 : signed(DI_C-1 downto 0)	 := x"19";
	constant SUPL_TBL_0DIM_SGD_09_C	 : signed(DI_C-1 downto 0)	 := x"1A";
	constant SUPL_TBL_0DIM_SGD_10_C	 : signed(DI_C-1 downto 0)	 := x"1B";
	constant SUPL_TBL_0DIM_SGD_11_C	 : signed(DI_C-1 downto 0)	 := x"1C";
	constant SUPL_TBL_0DIM_SGD_12_C	 : signed(DI_C-1 downto 0)	 := x"1D";
	constant SUPL_TBL_0DIM_SGD_13_C	 : signed(DI_C-1 downto 0)	 := x"1E";
	constant SUPL_TBL_0DIM_SGD_14_C  : signed(DI_C-1 downto 0)	 := x"1F";
	
	constant SUPL_TBL_0DIM_FLO_00_C	 : float_t					 := fill_float(16#1#);
	constant SUPL_TBL_0DIM_FLO_01_C	 : float_t					 := fill_float(16#2#);
	constant SUPL_TBL_0DIM_FLO_02_C	 : float_t					 := fill_float(16#3#);
	constant SUPL_TBL_0DIM_FLO_03_C	 : float_t					 := fill_float(16#4#);
	constant SUPL_TBL_0DIM_FLO_04_C	 : float_t					 := fill_float(16#5#);
	constant SUPL_TBL_0DIM_FLO_05_C	 : float_t					 := fill_float(16#6#);
	constant SUPL_TBL_0DIM_FLO_06_C	 : float_t					 := fill_float(16#7#);
	constant SUPL_TBL_0DIM_FLO_07_C	 : float_t					 := fill_float(16#8#);
	constant SUPL_TBL_0DIM_FLO_08_C	 : float_t					 := fill_float(16#9#);
	constant SUPL_TBL_0DIM_FLO_09_C	 : float_t					 := fill_float(16#A#);
	constant SUPL_TBL_0DIM_FLO_10_C	 : float_t					 := fill_float(16#B#);
	constant SUPL_TBL_0DIM_FLO_11_C	 : float_t					 := fill_float(16#C#);
	constant SUPL_TBL_0DIM_FLO_12_C	 : float_t					 := fill_float(16#D#);
	constant SUPL_TBL_0DIM_FLO_13_C	 : float_t					 := fill_float(16#E#);
	constant SUPL_TBL_0DIM_FLO_14_C  : float_t					 := fill_float(16#F#);
	
	constant SUPL_TBL_0DIM_USG_ARR_C : array_unsigned_t(0 to 14)(DI_C-1 downto 0) := (
		0  => SUPL_TBL_0DIM_USG_00_C,
		1  => SUPL_TBL_0DIM_USG_01_C,
		2  => SUPL_TBL_0DIM_USG_02_C,
		3  => SUPL_TBL_0DIM_USG_03_C,
		4  => SUPL_TBL_0DIM_USG_04_C,
		5  => SUPL_TBL_0DIM_USG_05_C,
		6  => SUPL_TBL_0DIM_USG_06_C,
		7  => SUPL_TBL_0DIM_USG_07_C,
		8  => SUPL_TBL_0DIM_USG_08_C,
		9  => SUPL_TBL_0DIM_USG_09_C,
		10 => SUPL_TBL_0DIM_USG_10_C,
		11 => SUPL_TBL_0DIM_USG_11_C,
		12 => SUPL_TBL_0DIM_USG_12_C,
		13 => SUPL_TBL_0DIM_USG_13_C,
		14 => SUPL_TBL_0DIM_USG_14_C
	);
	constant SUPL_TBL_0DIM_SGD_ARR_C : array_signed_t(0 to 14)(DI_C-1 downto 0) := (
		0  => SUPL_TBL_0DIM_SGD_00_C,
		1  => SUPL_TBL_0DIM_SGD_01_C,
		2  => SUPL_TBL_0DIM_SGD_02_C,
		3  => SUPL_TBL_0DIM_SGD_03_C,
		4  => SUPL_TBL_0DIM_SGD_04_C,
		5  => SUPL_TBL_0DIM_SGD_05_C,
		6  => SUPL_TBL_0DIM_SGD_06_C,
		7  => SUPL_TBL_0DIM_SGD_07_C,
		8  => SUPL_TBL_0DIM_SGD_08_C,
		9  => SUPL_TBL_0DIM_SGD_09_C,
		10 => SUPL_TBL_0DIM_SGD_10_C,
		11 => SUPL_TBL_0DIM_SGD_11_C,
		12 => SUPL_TBL_0DIM_SGD_12_C,
		13 => SUPL_TBL_0DIM_SGD_13_C,
		14 => SUPL_TBL_0DIM_SGD_14_C
	);
	constant SUPL_TBL_0DIM_FLO_ARR_C : array_float_t(0 to 14) := (
		0  => SUPL_TBL_0DIM_FLO_00_C,
		1  => SUPL_TBL_0DIM_FLO_01_C,
		2  => SUPL_TBL_0DIM_FLO_02_C,
		3  => SUPL_TBL_0DIM_FLO_03_C,
		4  => SUPL_TBL_0DIM_FLO_04_C,
		5  => SUPL_TBL_0DIM_FLO_05_C,
		6  => SUPL_TBL_0DIM_FLO_06_C,
		7  => SUPL_TBL_0DIM_FLO_07_C,
		8  => SUPL_TBL_0DIM_FLO_08_C,
		9  => SUPL_TBL_0DIM_FLO_09_C,
		10 => SUPL_TBL_0DIM_FLO_10_C,
		11 => SUPL_TBL_0DIM_FLO_11_C,
		12 => SUPL_TBL_0DIM_FLO_12_C,
		13 => SUPL_TBL_0DIM_FLO_13_C,
		14 => SUPL_TBL_0DIM_FLO_14_C
	);

-------------------------------------------------------------------------------------------------------------------
-------------------------------------------------------------------------------------------------------------------

	-- 1 dimensional tables (for unsigned, signed and float types, respectively)
	constant SUPL_TBL_1DIM_USG_00_C	 : array_unsigned_t(0 to NZ_C-1)(DI_C-1 downto 0) := (others => x"21");
	constant SUPL_TBL_1DIM_USG_01_C	 : array_unsigned_t(0 to NZ_C-1)(DI_C-1 downto 0) := (others => x"22");
	constant SUPL_TBL_1DIM_USG_02_C	 : array_unsigned_t(0 to NZ_C-1)(DI_C-1 downto 0) := (others => x"23");
	constant SUPL_TBL_1DIM_USG_03_C	 : array_unsigned_t(0 to NZ_C-1)(DI_C-1 downto 0) := (others => x"24");
	constant SUPL_TBL_1DIM_USG_04_C	 : array_unsigned_t(0 to NZ_C-1)(DI_C-1 downto 0) := (others => x"25");
	constant SUPL_TBL_1DIM_USG_05_C	 : array_unsigned_t(0 to NZ_C-1)(DI_C-1 downto 0) := (others => x"26");
	constant SUPL_TBL_1DIM_USG_06_C	 : array_unsigned_t(0 to NZ_C-1)(DI_C-1 downto 0) := (others => x"27");
	constant SUPL_TBL_1DIM_USG_07_C	 : array_unsigned_t(0 to NZ_C-1)(DI_C-1 downto 0) := (others => x"28");
	constant SUPL_TBL_1DIM_USG_08_C	 : array_unsigned_t(0 to NZ_C-1)(DI_C-1 downto 0) := (others => x"29");
	constant SUPL_TBL_1DIM_USG_09_C	 : array_unsigned_t(0 to NZ_C-1)(DI_C-1 downto 0) := (others => x"2A");
	constant SUPL_TBL_1DIM_USG_10_C	 : array_unsigned_t(0 to NZ_C-1)(DI_C-1 downto 0) := (others => x"2B");
	constant SUPL_TBL_1DIM_USG_11_C	 : array_unsigned_t(0 to NZ_C-1)(DI_C-1 downto 0) := (others => x"2C");
	constant SUPL_TBL_1DIM_USG_12_C	 : array_unsigned_t(0 to NZ_C-1)(DI_C-1 downto 0) := (others => x"2D");
	constant SUPL_TBL_1DIM_USG_13_C	 : array_unsigned_t(0 to NZ_C-1)(DI_C-1 downto 0) := (others => x"2E");
	constant SUPL_TBL_1DIM_USG_14_C	 : array_unsigned_t(0 to NZ_C-1)(DI_C-1 downto 0) := (others => x"2F");

	constant SUPL_TBL_1DIM_SGD_00_C	 : array_signed_t(0 to NZ_C-1)(DI_C-1 downto 0)	  := (others => x"31");
	constant SUPL_TBL_1DIM_SGD_01_C	 : array_signed_t(0 to NZ_C-1)(DI_C-1 downto 0)	  := (others => x"32");
	constant SUPL_TBL_1DIM_SGD_02_C	 : array_signed_t(0 to NZ_C-1)(DI_C-1 downto 0)	  := (others => x"33");
	constant SUPL_TBL_1DIM_SGD_03_C	 : array_signed_t(0 to NZ_C-1)(DI_C-1 downto 0)	  := (others => x"34");
	constant SUPL_TBL_1DIM_SGD_04_C	 : array_signed_t(0 to NZ_C-1)(DI_C-1 downto 0)	  := (others => x"35");
	constant SUPL_TBL_1DIM_SGD_05_C	 : array_signed_t(0 to NZ_C-1)(DI_C-1 downto 0)	  := (others => x"36");
	constant SUPL_TBL_1DIM_SGD_06_C	 : array_signed_t(0 to NZ_C-1)(DI_C-1 downto 0)	  := (others => x"37");
	constant SUPL_TBL_1DIM_SGD_07_C	 : array_signed_t(0 to NZ_C-1)(DI_C-1 downto 0)	  := (others => x"38");
	constant SUPL_TBL_1DIM_SGD_08_C	 : array_signed_t(0 to NZ_C-1)(DI_C-1 downto 0)	  := (others => x"39");
	constant SUPL_TBL_1DIM_SGD_09_C	 : array_signed_t(0 to NZ_C-1)(DI_C-1 downto 0)	  := (others => x"3A");
	constant SUPL_TBL_1DIM_SGD_10_C	 : array_signed_t(0 to NZ_C-1)(DI_C-1 downto 0)	  := (others => x"3B");
	constant SUPL_TBL_1DIM_SGD_11_C	 : array_signed_t(0 to NZ_C-1)(DI_C-1 downto 0)	  := (others => x"3C");
	constant SUPL_TBL_1DIM_SGD_12_C	 : array_signed_t(0 to NZ_C-1)(DI_C-1 downto 0)	  := (others => x"3D");
	constant SUPL_TBL_1DIM_SGD_13_C	 : array_signed_t(0 to NZ_C-1)(DI_C-1 downto 0)	  := (others => x"3E");
	constant SUPL_TBL_1DIM_SGD_14_C	 : array_signed_t(0 to NZ_C-1)(DI_C-1 downto 0)	  := (others => x"3F");

	constant SUPL_TBL_1DIM_FLO_00_C	 : array_float_t(0 to NZ_C-1)					  := (others => fill_float(16#11#));
	constant SUPL_TBL_1DIM_FLO_01_C	 : array_float_t(0 to NZ_C-1)					  := (others => fill_float(16#12#));
	constant SUPL_TBL_1DIM_FLO_02_C	 : array_float_t(0 to NZ_C-1)					  := (others => fill_float(16#13#));
	constant SUPL_TBL_1DIM_FLO_03_C	 : array_float_t(0 to NZ_C-1)					  := (others => fill_float(16#14#));
	constant SUPL_TBL_1DIM_FLO_04_C	 : array_float_t(0 to NZ_C-1)					  := (others => fill_float(16#15#));
	constant SUPL_TBL_1DIM_FLO_05_C	 : array_float_t(0 to NZ_C-1)					  := (others => fill_float(16#16#));
	constant SUPL_TBL_1DIM_FLO_06_C	 : array_float_t(0 to NZ_C-1)					  := (others => fill_float(16#17#));
	constant SUPL_TBL_1DIM_FLO_07_C	 : array_float_t(0 to NZ_C-1)					  := (others => fill_float(16#18#));
	constant SUPL_TBL_1DIM_FLO_08_C	 : array_float_t(0 to NZ_C-1)					  := (others => fill_float(16#19#));
	constant SUPL_TBL_1DIM_FLO_09_C	 : array_float_t(0 to NZ_C-1)					  := (others => fill_float(16#1A#));
	constant SUPL_TBL_1DIM_FLO_10_C	 : array_float_t(0 to NZ_C-1)					  := (others => fill_float(16#1B#));
	constant SUPL_TBL_1DIM_FLO_11_C	 : array_float_t(0 to NZ_C-1)					  := (others => fill_float(16#1C#));
	constant SUPL_TBL_1DIM_FLO_12_C	 : array_float_t(0 to NZ_C-1)					  := (others => fill_float(16#1D#));
	constant SUPL_TBL_1DIM_FLO_13_C	 : array_float_t(0 to NZ_C-1)					  := (others => fill_float(16#1E#));
	constant SUPL_TBL_1DIM_FLO_14_C	 : array_float_t(0 to NZ_C-1)					  := (others => fill_float(16#1F#));

	constant SUPL_TBL_1DIM_USG_ARR_C : matrix_unsigned_t(0 to 14)(0 to NZ_C-1)(DI_C-1 downto 0)	:= (
		0  => SUPL_TBL_1DIM_USG_00_C,
		1  => SUPL_TBL_1DIM_USG_01_C,
		2  => SUPL_TBL_1DIM_USG_02_C,
		3  => SUPL_TBL_1DIM_USG_03_C,
		4  => SUPL_TBL_1DIM_USG_04_C,
		5  => SUPL_TBL_1DIM_USG_05_C,
		6  => SUPL_TBL_1DIM_USG_06_C,
		7  => SUPL_TBL_1DIM_USG_07_C,
		8  => SUPL_TBL_1DIM_USG_08_C,
		9  => SUPL_TBL_1DIM_USG_09_C,
		10 => SUPL_TBL_1DIM_USG_10_C,
		11 => SUPL_TBL_1DIM_USG_11_C,
		12 => SUPL_TBL_1DIM_USG_12_C,
		13 => SUPL_TBL_1DIM_USG_13_C,
		14 => SUPL_TBL_1DIM_USG_14_C
	);
	constant SUPL_TBL_1DIM_SGD_ARR_C : matrix_signed_t(0 to 14)(0 to NZ_C-1)(DI_C-1 downto 0)	:= (
		0  => SUPL_TBL_1DIM_SGD_00_C,
		1  => SUPL_TBL_1DIM_SGD_01_C,
		2  => SUPL_TBL_1DIM_SGD_02_C,
		3  => SUPL_TBL_1DIM_SGD_03_C,
		4  => SUPL_TBL_1DIM_SGD_04_C,
		5  => SUPL_TBL_1DIM_SGD_05_C,
		6  => SUPL_TBL_1DIM_SGD_06_C,
		7  => SUPL_TBL_1DIM_SGD_07_C,
		8  => SUPL_TBL_1DIM_SGD_08_C,
		9  => SUPL_TBL_1DIM_SGD_09_C,
		10 => SUPL_TBL_1DIM_SGD_10_C,
		11 => SUPL_TBL_1DIM_SGD_11_C,
		12 => SUPL_TBL_1DIM_SGD_12_C,
		13 => SUPL_TBL_1DIM_SGD_13_C,
		14 => SUPL_TBL_1DIM_SGD_14_C
	);
	constant SUPL_TBL_1DIM_FLO_ARR_C : matrix_float_t(0 to 14)(0 to NZ_C-1)						:= (
		0  => SUPL_TBL_1DIM_FLO_00_C,
		1  => SUPL_TBL_1DIM_FLO_01_C,
		2  => SUPL_TBL_1DIM_FLO_02_C,
		3  => SUPL_TBL_1DIM_FLO_03_C,
		4  => SUPL_TBL_1DIM_FLO_04_C,
		5  => SUPL_TBL_1DIM_FLO_05_C,
		6  => SUPL_TBL_1DIM_FLO_06_C,
		7  => SUPL_TBL_1DIM_FLO_07_C,
		8  => SUPL_TBL_1DIM_FLO_08_C,
		9  => SUPL_TBL_1DIM_FLO_09_C,
		10 => SUPL_TBL_1DIM_FLO_10_C,
		11 => SUPL_TBL_1DIM_FLO_11_C,
		12 => SUPL_TBL_1DIM_FLO_12_C,
		13 => SUPL_TBL_1DIM_FLO_13_C,
		14 => SUPL_TBL_1DIM_FLO_14_C
	);

-------------------------------------------------------------------------------------------------------------------
-------------------------------------------------------------------------------------------------------------------

	-- 2 dimensional Z-X tables (for unsigned, signed and float types, respectively)
	constant SUPL_TBL_2DIM_ZX_USG_00_C	: matrix_unsigned_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"41"));
	constant SUPL_TBL_2DIM_ZX_USG_01_C	: matrix_unsigned_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"42"));
	constant SUPL_TBL_2DIM_ZX_USG_02_C	: matrix_unsigned_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"43"));
	constant SUPL_TBL_2DIM_ZX_USG_03_C	: matrix_unsigned_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"44"));
	constant SUPL_TBL_2DIM_ZX_USG_04_C	: matrix_unsigned_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"45"));
	constant SUPL_TBL_2DIM_ZX_USG_05_C	: matrix_unsigned_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"46"));
	constant SUPL_TBL_2DIM_ZX_USG_06_C	: matrix_unsigned_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"47"));
	constant SUPL_TBL_2DIM_ZX_USG_07_C	: matrix_unsigned_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"48"));
	constant SUPL_TBL_2DIM_ZX_USG_08_C	: matrix_unsigned_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"49"));
	constant SUPL_TBL_2DIM_ZX_USG_09_C	: matrix_unsigned_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"4A"));
	constant SUPL_TBL_2DIM_ZX_USG_10_C	: matrix_unsigned_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"4B"));
	constant SUPL_TBL_2DIM_ZX_USG_11_C	: matrix_unsigned_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"4C"));
	constant SUPL_TBL_2DIM_ZX_USG_12_C	: matrix_unsigned_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"4D"));
	constant SUPL_TBL_2DIM_ZX_USG_13_C	: matrix_unsigned_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"4E"));
	constant SUPL_TBL_2DIM_ZX_USG_14_C	: matrix_unsigned_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"4F"));

	constant SUPL_TBL_2DIM_ZX_SGD_00_C	: matrix_signed_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"51"));
	constant SUPL_TBL_2DIM_ZX_SGD_01_C	: matrix_signed_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"52"));
	constant SUPL_TBL_2DIM_ZX_SGD_02_C	: matrix_signed_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"53"));
	constant SUPL_TBL_2DIM_ZX_SGD_03_C	: matrix_signed_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"54"));
	constant SUPL_TBL_2DIM_ZX_SGD_04_C	: matrix_signed_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"55"));
	constant SUPL_TBL_2DIM_ZX_SGD_05_C	: matrix_signed_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"56"));
	constant SUPL_TBL_2DIM_ZX_SGD_06_C	: matrix_signed_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"57"));
	constant SUPL_TBL_2DIM_ZX_SGD_07_C	: matrix_signed_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"58"));
	constant SUPL_TBL_2DIM_ZX_SGD_08_C	: matrix_signed_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"59"));
	constant SUPL_TBL_2DIM_ZX_SGD_09_C	: matrix_signed_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"5A"));
	constant SUPL_TBL_2DIM_ZX_SGD_10_C	: matrix_signed_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"5B"));
	constant SUPL_TBL_2DIM_ZX_SGD_11_C	: matrix_signed_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"5C"));
	constant SUPL_TBL_2DIM_ZX_SGD_12_C	: matrix_signed_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"5D"));
	constant SUPL_TBL_2DIM_ZX_SGD_13_C	: matrix_signed_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"5E"));
	constant SUPL_TBL_2DIM_ZX_SGD_14_C	: matrix_signed_t(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"5F"));

	constant SUPL_TBL_2DIM_ZX_FLO_00_C	: matrix_float_t(0 to NZ_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#21#)));
	constant SUPL_TBL_2DIM_ZX_FLO_01_C	: matrix_float_t(0 to NZ_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#22#)));
	constant SUPL_TBL_2DIM_ZX_FLO_02_C	: matrix_float_t(0 to NZ_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#23#)));
	constant SUPL_TBL_2DIM_ZX_FLO_03_C	: matrix_float_t(0 to NZ_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#24#)));
	constant SUPL_TBL_2DIM_ZX_FLO_04_C	: matrix_float_t(0 to NZ_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#25#)));
	constant SUPL_TBL_2DIM_ZX_FLO_05_C	: matrix_float_t(0 to NZ_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#26#)));
	constant SUPL_TBL_2DIM_ZX_FLO_06_C	: matrix_float_t(0 to NZ_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#27#)));
	constant SUPL_TBL_2DIM_ZX_FLO_07_C	: matrix_float_t(0 to NZ_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#28#)));
	constant SUPL_TBL_2DIM_ZX_FLO_08_C	: matrix_float_t(0 to NZ_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#29#)));
	constant SUPL_TBL_2DIM_ZX_FLO_09_C	: matrix_float_t(0 to NZ_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#2A#)));
	constant SUPL_TBL_2DIM_ZX_FLO_10_C	: matrix_float_t(0 to NZ_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#2B#)));
	constant SUPL_TBL_2DIM_ZX_FLO_11_C	: matrix_float_t(0 to NZ_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#2C#)));
	constant SUPL_TBL_2DIM_ZX_FLO_12_C	: matrix_float_t(0 to NZ_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#2D#)));
	constant SUPL_TBL_2DIM_ZX_FLO_13_C	: matrix_float_t(0 to NZ_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#2E#)));
	constant SUPL_TBL_2DIM_ZX_FLO_14_C	: matrix_float_t(0 to NZ_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#2F#)));

	constant SUPL_TBL_2DIM_ZX_USG_ARR_C	: matrix3D_unsigned_t(0 to 14)(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (
		0  => SUPL_TBL_2DIM_ZX_USG_00_C,
		1  => SUPL_TBL_2DIM_ZX_USG_01_C,
		2  => SUPL_TBL_2DIM_ZX_USG_02_C,
		3  => SUPL_TBL_2DIM_ZX_USG_03_C,
		4  => SUPL_TBL_2DIM_ZX_USG_04_C,
		5  => SUPL_TBL_2DIM_ZX_USG_05_C,
		6  => SUPL_TBL_2DIM_ZX_USG_06_C,
		7  => SUPL_TBL_2DIM_ZX_USG_07_C,
		8  => SUPL_TBL_2DIM_ZX_USG_08_C,
		9  => SUPL_TBL_2DIM_ZX_USG_09_C,
		10 => SUPL_TBL_2DIM_ZX_USG_10_C,
		11 => SUPL_TBL_2DIM_ZX_USG_11_C,
		12 => SUPL_TBL_2DIM_ZX_USG_12_C,
		13 => SUPL_TBL_2DIM_ZX_USG_13_C,
		14 => SUPL_TBL_2DIM_ZX_USG_14_C
	);
	constant SUPL_TBL_2DIM_ZX_SGD_ARR_C : matrix3D_signed_t(0 to 14)(0 to NZ_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (
		0  => SUPL_TBL_2DIM_ZX_SGD_00_C,
		1  => SUPL_TBL_2DIM_ZX_SGD_01_C,
		2  => SUPL_TBL_2DIM_ZX_SGD_02_C,
		3  => SUPL_TBL_2DIM_ZX_SGD_03_C,
		4  => SUPL_TBL_2DIM_ZX_SGD_04_C,
		5  => SUPL_TBL_2DIM_ZX_SGD_05_C,
		6  => SUPL_TBL_2DIM_ZX_SGD_06_C,
		7  => SUPL_TBL_2DIM_ZX_SGD_07_C,
		8  => SUPL_TBL_2DIM_ZX_SGD_08_C,
		9  => SUPL_TBL_2DIM_ZX_SGD_09_C,
		10 => SUPL_TBL_2DIM_ZX_SGD_10_C,
		11 => SUPL_TBL_2DIM_ZX_SGD_11_C,
		12 => SUPL_TBL_2DIM_ZX_SGD_12_C,
		13 => SUPL_TBL_2DIM_ZX_SGD_13_C,
		14 => SUPL_TBL_2DIM_ZX_SGD_14_C
	);
	constant SUPL_TBL_2DIM_ZX_FLO_ARR_C : matrix3D_float_t(0 to 14)(0 to NZ_C-1)(0 to NX_C-1)						:= (
		0  => SUPL_TBL_2DIM_ZX_FLO_00_C,
		1  => SUPL_TBL_2DIM_ZX_FLO_01_C,
		2  => SUPL_TBL_2DIM_ZX_FLO_02_C,
		3  => SUPL_TBL_2DIM_ZX_FLO_03_C,
		4  => SUPL_TBL_2DIM_ZX_FLO_04_C,
		5  => SUPL_TBL_2DIM_ZX_FLO_05_C,
		6  => SUPL_TBL_2DIM_ZX_FLO_06_C,
		7  => SUPL_TBL_2DIM_ZX_FLO_07_C,
		8  => SUPL_TBL_2DIM_ZX_FLO_08_C,
		9  => SUPL_TBL_2DIM_ZX_FLO_09_C,
		10 => SUPL_TBL_2DIM_ZX_FLO_10_C,
		11 => SUPL_TBL_2DIM_ZX_FLO_11_C,
		12 => SUPL_TBL_2DIM_ZX_FLO_12_C,
		13 => SUPL_TBL_2DIM_ZX_FLO_13_C,
		14 => SUPL_TBL_2DIM_ZX_FLO_14_C
	);

-------------------------------------------------------------------------------------------------------------------
-------------------------------------------------------------------------------------------------------------------

	-- 2 dimensional Y-X tables (for unsigned, signed and float types, respectively)
	constant SUPL_TBL_2DIM_YX_USG_00_C	: matrix_unsigned_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"61"));
	constant SUPL_TBL_2DIM_YX_USG_01_C	: matrix_unsigned_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"62"));
	constant SUPL_TBL_2DIM_YX_USG_02_C	: matrix_unsigned_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"63"));
	constant SUPL_TBL_2DIM_YX_USG_03_C	: matrix_unsigned_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"64"));
	constant SUPL_TBL_2DIM_YX_USG_04_C	: matrix_unsigned_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"65"));
	constant SUPL_TBL_2DIM_YX_USG_05_C	: matrix_unsigned_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"66"));
	constant SUPL_TBL_2DIM_YX_USG_06_C	: matrix_unsigned_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"67"));
	constant SUPL_TBL_2DIM_YX_USG_07_C	: matrix_unsigned_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"68"));
	constant SUPL_TBL_2DIM_YX_USG_08_C	: matrix_unsigned_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"69"));
	constant SUPL_TBL_2DIM_YX_USG_09_C	: matrix_unsigned_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"6A"));
	constant SUPL_TBL_2DIM_YX_USG_10_C	: matrix_unsigned_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"6B"));
	constant SUPL_TBL_2DIM_YX_USG_11_C	: matrix_unsigned_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"6C"));
	constant SUPL_TBL_2DIM_YX_USG_12_C	: matrix_unsigned_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"6D"));
	constant SUPL_TBL_2DIM_YX_USG_13_C	: matrix_unsigned_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"6E"));
	constant SUPL_TBL_2DIM_YX_USG_14_C	: matrix_unsigned_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"6F"));

	constant SUPL_TBL_2DIM_YX_SGD_00_C	: matrix_signed_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"71"));
	constant SUPL_TBL_2DIM_YX_SGD_01_C	: matrix_signed_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"72"));
	constant SUPL_TBL_2DIM_YX_SGD_02_C	: matrix_signed_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"73"));
	constant SUPL_TBL_2DIM_YX_SGD_03_C	: matrix_signed_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"74"));
	constant SUPL_TBL_2DIM_YX_SGD_04_C	: matrix_signed_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"75"));
	constant SUPL_TBL_2DIM_YX_SGD_05_C	: matrix_signed_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"76"));
	constant SUPL_TBL_2DIM_YX_SGD_06_C	: matrix_signed_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"77"));
	constant SUPL_TBL_2DIM_YX_SGD_07_C	: matrix_signed_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"78"));
	constant SUPL_TBL_2DIM_YX_SGD_08_C	: matrix_signed_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"79"));
	constant SUPL_TBL_2DIM_YX_SGD_09_C	: matrix_signed_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"7A"));
	constant SUPL_TBL_2DIM_YX_SGD_10_C	: matrix_signed_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"7B"));
	constant SUPL_TBL_2DIM_YX_SGD_11_C	: matrix_signed_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"7C"));
	constant SUPL_TBL_2DIM_YX_SGD_12_C	: matrix_signed_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"7D"));
	constant SUPL_TBL_2DIM_YX_SGD_13_C	: matrix_signed_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"7E"));
	constant SUPL_TBL_2DIM_YX_SGD_14_C	: matrix_signed_t(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (others => (others => x"7F"));

	constant SUPL_TBL_2DIM_YX_FLO_00_C	: matrix_float_t(0 to NY_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#31#)));
	constant SUPL_TBL_2DIM_YX_FLO_01_C	: matrix_float_t(0 to NY_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#32#)));
	constant SUPL_TBL_2DIM_YX_FLO_02_C	: matrix_float_t(0 to NY_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#33#)));
	constant SUPL_TBL_2DIM_YX_FLO_03_C	: matrix_float_t(0 to NY_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#34#)));
	constant SUPL_TBL_2DIM_YX_FLO_04_C	: matrix_float_t(0 to NY_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#35#)));
	constant SUPL_TBL_2DIM_YX_FLO_05_C	: matrix_float_t(0 to NY_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#36#)));
	constant SUPL_TBL_2DIM_YX_FLO_06_C	: matrix_float_t(0 to NY_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#37#)));
	constant SUPL_TBL_2DIM_YX_FLO_07_C	: matrix_float_t(0 to NY_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#38#)));
	constant SUPL_TBL_2DIM_YX_FLO_08_C	: matrix_float_t(0 to NY_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#39#)));
	constant SUPL_TBL_2DIM_YX_FLO_09_C	: matrix_float_t(0 to NY_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#3A#)));
	constant SUPL_TBL_2DIM_YX_FLO_10_C	: matrix_float_t(0 to NY_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#3B#)));
	constant SUPL_TBL_2DIM_YX_FLO_11_C	: matrix_float_t(0 to NY_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#3C#)));
	constant SUPL_TBL_2DIM_YX_FLO_12_C	: matrix_float_t(0 to NY_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#3D#)));
	constant SUPL_TBL_2DIM_YX_FLO_13_C	: matrix_float_t(0 to NY_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#3E#)));
	constant SUPL_TBL_2DIM_YX_FLO_14_C	: matrix_float_t(0 to NY_C-1)(0 to NX_C-1)						:= (others => (others => fill_float(16#3F#)));

	constant SUPL_TBL_2DIM_YX_USG_ARR_C	: matrix3D_unsigned_t(0 to 14)(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (
		0  => SUPL_TBL_2DIM_YX_USG_00_C,
		1  => SUPL_TBL_2DIM_YX_USG_01_C,
		2  => SUPL_TBL_2DIM_YX_USG_02_C,
		3  => SUPL_TBL_2DIM_YX_USG_03_C,
		4  => SUPL_TBL_2DIM_YX_USG_04_C,
		5  => SUPL_TBL_2DIM_YX_USG_05_C,
		6  => SUPL_TBL_2DIM_YX_USG_06_C,
		7  => SUPL_TBL_2DIM_YX_USG_07_C,
		8  => SUPL_TBL_2DIM_YX_USG_08_C,
		9  => SUPL_TBL_2DIM_YX_USG_09_C,
		10 => SUPL_TBL_2DIM_YX_USG_10_C,
		11 => SUPL_TBL_2DIM_YX_USG_11_C,
		12 => SUPL_TBL_2DIM_YX_USG_12_C,
		13 => SUPL_TBL_2DIM_YX_USG_13_C,
		14 => SUPL_TBL_2DIM_YX_USG_14_C
	);
	constant SUPL_TBL_2DIM_YX_SGD_ARR_C : matrix3D_signed_t(0 to 14)(0 to NY_C-1)(0 to NX_C-1)(DI_C-1 downto 0)	:= (
		0  => SUPL_TBL_2DIM_YX_SGD_00_C,
		1  => SUPL_TBL_2DIM_YX_SGD_01_C,
		2  => SUPL_TBL_2DIM_YX_SGD_02_C,
		3  => SUPL_TBL_2DIM_YX_SGD_03_C,
		4  => SUPL_TBL_2DIM_YX_SGD_04_C,
		5  => SUPL_TBL_2DIM_YX_SGD_05_C,
		6  => SUPL_TBL_2DIM_YX_SGD_06_C,
		7  => SUPL_TBL_2DIM_YX_SGD_07_C,
		8  => SUPL_TBL_2DIM_YX_SGD_08_C,
		9  => SUPL_TBL_2DIM_YX_SGD_09_C,
		10 => SUPL_TBL_2DIM_YX_SGD_10_C,
		11 => SUPL_TBL_2DIM_YX_SGD_11_C,
		12 => SUPL_TBL_2DIM_YX_SGD_12_C,
		13 => SUPL_TBL_2DIM_YX_SGD_13_C,
		14 => SUPL_TBL_2DIM_YX_SGD_14_C
	);
	constant SUPL_TBL_2DIM_YX_FLO_ARR_C : matrix3D_float_t(0 to 14)(0 to NY_C-1)(0 to NX_C-1)						:= (
		0  => SUPL_TBL_2DIM_YX_FLO_00_C,
		1  => SUPL_TBL_2DIM_YX_FLO_01_C,
		2  => SUPL_TBL_2DIM_YX_FLO_02_C,
		3  => SUPL_TBL_2DIM_YX_FLO_03_C,
		4  => SUPL_TBL_2DIM_YX_FLO_04_C,
		5  => SUPL_TBL_2DIM_YX_FLO_05_C,
		6  => SUPL_TBL_2DIM_YX_FLO_06_C,
		7  => SUPL_TBL_2DIM_YX_FLO_07_C,
		8  => SUPL_TBL_2DIM_YX_FLO_08_C,
		9  => SUPL_TBL_2DIM_YX_FLO_09_C,
		10 => SUPL_TBL_2DIM_YX_FLO_10_C,
		11 => SUPL_TBL_2DIM_YX_FLO_11_C,
		12 => SUPL_TBL_2DIM_YX_FLO_12_C,
		13 => SUPL_TBL_2DIM_YX_FLO_13_C,
		14 => SUPL_TBL_2DIM_YX_FLO_14_C
	);

end package supl_info_tables;